@@ -7,7 +7,7 @@ Module: Collect/MYD11
 import sys
 from watertools.Collect.MYD11.DataAccess import DownloadData
 
-def main(Dir, Startdate, Enddate, latlim, lonlim, Waitbar = 1, hdf_library = None, remove_hdf = 1, angle_info = 0, time_info = 0):
+def main(Dir, Startdate, Enddate, latlim, lonlim, Waitbar = 1, cores=False, hdf_library = None, remove_hdf = 1, angle_info = 0, time_info = 0):
     """
     This function downloads MYD11 daily data for the specified time
     interval, and spatial extent.
@@ -26,7 +26,7 @@ def main(Dir, Startdate, Enddate, latlim, lonlim, Waitbar = 1, hdf_library = Non
 
     print('\nDownload daily MODIS land surface temperature data for period %s till %s' %(Startdate, Enddate))
     TimeStep = 1
-    DownloadData(Dir, Startdate, Enddate, latlim, lonlim, TimeStep, Waitbar, hdf_library, remove_hdf, angle_info, time_info)
+    DownloadData(Dir, Startdate, Enddate, latlim, lonlim, TimeStep, Waitbar, cores, hdf_library, remove_hdf, angle_info, time_info)
 
 if __name__ == '__main__':
     main(sys.argv)
\ No newline at end of file
